pub enum OperationId {
Show 23 variants
Blur,
Brighten,
Contrast,
Crop,
Diff,
DrawText,
Filter3x3,
FlipHorizontal,
FlipVertical,
Grayscale,
HueRotate,
HorizontalGradient,
Invert,
Overlay,
Resize,
Rotate90,
Rotate180,
Rotate270,
Threshold,
Unsharpen,
VerticalGradient,
PreserveAspectRatio,
SamplingFilter,
}Expand description
The enumeration of all supported operations.
Variants
Blur
Brighten
Contrast
Crop
Diff
DrawText
Filter3x3
FlipHorizontal
FlipVertical
Grayscale
HueRotate
HorizontalGradient
Invert
Overlay
Resize
Rotate90
Rotate180
Rotate270
Threshold
Unsharpen
VerticalGradient
PreserveAspectRatio
SamplingFilter
Implementations
Sourceimpl OperationId
impl OperationId
pub fn variants() -> &'static [&'static str]
pub fn try_from_name(input: &str) -> TResult<Self>
Sourcepub fn takes_number_of_arguments(self) -> usize
pub fn takes_number_of_arguments(self) -> usize
Provides the number of arguments an operation takes.
Used to unify arguments together.
E.g. (without accounting for the requirement of having incremental indices as well),
say we receive for resize the values 10, 20, 100 and 100. With the number of values we know
that each resize operation takes two arguments, not four. So it could be that there are
two operations, namely resize 10 20 and resize 100 100. We do need to take some other
conditions into account, but they are not relevant for this particular method =).
Sourceimpl OperationId
impl OperationId
Sourcepub fn create_instruction<'a, T>(
self,
inputs: T,
) -> Result<Instr, SicCliOpsError>
pub fn create_instruction<'a, T>( self, inputs: T, ) -> Result<Instr, SicCliOpsError>
Constructs instructions for image operations which are taken as input by the image engine.